@@ -25,8 +25,9 @@
 #' @family samplers
 #'
 sample_igraph <- function(
-    factor_model,
-    ...) {
+  factor_model,
+  ...
+) {
   rlang::check_dots_unnamed()
 
   rlang::check_installed("igraph", "to return graphs as `igraph` objects.")
@@ -37,8 +38,9 @@ sample_igraph <- function(
 #' @rdname sample_igraph
 #' @export
 sample_igraph.undirected_factor_model <- function(
-    factor_model,
-    ...) {
+  factor_model,
+  ...
+) {
   edgelist <- sample_edgelist(factor_model, ...)
   nodes <- tibble(name = 1:nrow(factor_model$X))
   igraph::graph_from_data_frame(edgelist, directed = FALSE, vertices = nodes)
@@ -47,12 +49,17 @@ sample_igraph.undirected_factor_model <- function(
 #' @rdname sample_igraph
 #' @export
 sample_igraph.directed_factor_model <- function(
-    factor_model,
-    ...) {
+  factor_model,
+  ...
+) {
   if (factor_model$n == factor_model$d) {
     edgelist <- sample_edgelist(factor_model, ...)
     nodes <- tibble(name = 1:nrow(factor_model$X))
-    one_mode <- igraph::graph_from_data_frame(edgelist, directed = TRUE, vertices = nodes)
+    one_mode <- igraph::graph_from_data_frame(
+      edgelist,
+      directed = TRUE,
+      vertices = nodes
+    )
     return(one_mode)
   }
 
@@ -60,5 +67,5 @@ sample_igraph.directed_factor_model <- function(
   # a bipartite graph rather than using the usual one-mode tools
 
   A <- sample_sparse(factor_model, ...)
-  igraph::graph_from_incidence_matrix(A, directed = FALSE, multiple = TRUE)
+  igraph::graph_from_biadjacency_matrix(A, directed = FALSE, multiple = TRUE)
 }
