@@ -10,7 +10,8 @@ test_that("undirected graphs allow_self_loops = FALSE", {
   S <- matrix(runif(n = k * k, 0, .1), nrow = k)
 
   ufm <- undirected_factor_model(
-    X, S,
+    X,
+    S,
     expected_density = 0.1,
     allow_self_loops = FALSE
   )
@@ -22,12 +23,12 @@ test_that("undirected graphs allow_self_loops = FALSE", {
   expect_false(any(diag(A) > 0))
 
   igraph <- sample_igraph(ufm)
-  expect_false(any(diag(get.adjacency(igraph)) > 0))
+  expect_false(any(diag(as_adjacency_matrix(igraph)) > 0))
 
   ### sampling graphs as tidygraph graphs ---------------
 
   tbl_graph <- sample_tidygraph(ufm)
-  expect_false(any(diag(get.adjacency(tbl_graph)) > 0))
+  expect_false(any(diag(as_adjacency_matrix(tbl_graph)) > 0))
 })
 
 test_that("directed graphs allow_self_loops = FALSE", {
@@ -44,7 +45,13 @@ test_that("directed graphs allow_self_loops = FALSE", {
   S <- matrix(runif(n = k1 * k2, 0, .1), nrow = k1, ncol = k2)
   Y <- matrix(rexp(n = k2 * d, 1), nrow = d)
 
-  fm <- directed_factor_model(X, S, Y, expected_density = 0.01, allow_self_loops = FALSE)
+  fm <- directed_factor_model(
+    X,
+    S,
+    Y,
+    expected_density = 0.01,
+    allow_self_loops = FALSE
+  )
 
   edgelist <- sample_edgelist(fm)
   expect_false(any(edgelist$from == edgelist$to))
@@ -53,10 +60,10 @@ test_that("directed graphs allow_self_loops = FALSE", {
   expect_false(any(diag(A) > 0))
 
   igraph <- sample_igraph(fm)
-  expect_false(any(diag(get.adjacency(igraph)) > 0))
+  expect_false(any(diag(as_adjacency_matrix(igraph)) > 0))
 
   ### sampling graphs as tidygraph graphs ---------------
 
   tbl_graph <- sample_tidygraph(fm)
-  expect_false(any(diag(get.adjacency(tbl_graph)) > 0))
+  expect_false(any(diag(as_adjacency_matrix(tbl_graph)) > 0))
 })
